@@ -52,12 +52,12 @@
 
 #define MOD_SMOOTH_STREAMING_VERSION_MAJOR      1
 #define MOD_SMOOTH_STREAMING_VERSION_MINOR      11
-#define MOD_SMOOTH_STREAMING_VERSION_REVISION   14
+#define MOD_SMOOTH_STREAMING_VERSION_REVISION   17
 
 #define X_MOD_SMOOTH_STREAMING_KEY         "X-Mod-Smooth-Streaming"
 
 // This repeats the #defines above, but it is grepped for...
-#define X_MOD_SMOOTH_STREAMING_VERSION     "version=1.11.14"
+#define X_MOD_SMOOTH_STREAMING_VERSION     "version=1.11.17"
 
 #ifdef __cplusplus
 #define __STDC_FORMAT_MACROS    // C++ should define this for PRIu64
@@ -69,6 +69,19 @@
 # define snprintf _snprintf
 #endif
 
+#if defined(__cplusplus) && __cplusplus >= 201703L
+#  define MP4_NODISCARD [[nodiscard]]
+#elif defined(__GNUC__) // also works for clang
+#  define MP4_NODISCARD __attribute__((__warn_unused_result__))
+#elif defined(_MSC_VER)
+// Unfortunately MSVC's _Check_return only works in "Code Analysis" mode, not
+// during regular compilation, and you also need to include <sal.h> to be able
+// to use it.
+#  define MP4_NODISCARD// _Check_return_
+#else
+#  define MP4_NODISCARD
+#endif
+
 #ifdef __cplusplus
 extern "C" {
 #endif
