@@ -1051,7 +1051,7 @@ ngx_streaming_handler_post(ngx_http_request_t *r, mp4_process_context_t* ctx)
 
   if(!strcmp(file, "purge"))
   {
-    int result = mp4_process(ctx);
+    fmp4_result result = mp4_process(ctx);
 
     if(result != NGX_HTTP_OK)
     {
@@ -1463,7 +1463,12 @@ ngx_streaming_handler_get(ngx_http_request_t *r,
             uint64_t offset;
             uint64_t size = 0;
             uint32_t max_size = 16 * 1024 * 1024;
-            bucket_file_read(bucket, &fname, &offset, &size, max_size);
+            fmp4_result result = bucket_file_read(bucket, &fname, &offset, &size, max_size);
+            if(result != FMP4_OK)
+            {
+              ngx_log_error(NGX_LOG_ERR, log, 0, "bucket_file_read failed: %s",
+                            fmp4_result_to_string(result));
+            }
 
             b->file = ngx_pcalloc(r->pool, sizeof(ngx_file_t));
             if(b->file == NULL)
@@ -1508,7 +1513,12 @@ ngx_streaming_handler_get(ngx_http_request_t *r,
           {
             uint8_t const* src = 0;
             size_t size = 0;
-            bucket_read(bucket, &src, &size);
+            fmp4_result result = bucket_read(bucket, &src, &size);
+            if(result != FMP4_OK)
+            {
+              ngx_log_error(NGX_LOG_ERR, log, 0, "bucket_read failed: %s",
+                            fmp4_result_to_string(result));
+            }
 
             b->pos = ngx_pcalloc(r->pool, size);
             if(b->pos == NULL)
